@@ -1,24 +1,10 @@
 /*
+    SPDX-FileCopyrightText: 2001 The Kompany
+    SPDX-FileCopyrightText: 2002-2003 Ilya Konstantinov <kde-devel@future.shiny.co.il>
+    SPDX-FileCopyrightText: 2002-2003 Marcus Meissner <marcus@jet.franken.de>
+    SPDX-FileCopyrightText: 2003 Nadeem Hasan <nhasan@nadmm.com>
 
-    Copyright (C) 2001 The Kompany
-          2002-2003	Ilya Konstantinov <kde-devel@future.shiny.co.il>
-          2002-2003	Marcus Meissner <marcus@jet.franken.de>
-          2003		Nadeem Hasan <nhasan@nadmm.com>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kameraconfigdialog.h"
@@ -38,8 +24,7 @@
 
 #include <KLocalizedString>
 
-#include <QLoggingCategory>
-Q_DECLARE_LOGGING_CATEGORY(KAMERA_KCONTROL)
+#include "kcm_kamera_log.h"
 
 KameraConfigDialog::KameraConfigDialog(Camera */*camera*/,
                     CameraWidget *widget,
@@ -47,11 +32,11 @@ KameraConfigDialog::KameraConfigDialog(Camera */*camera*/,
     QDialog(parent),
     m_widgetRoot(widget)
 {
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(
+    auto buttonBox = new QDialogButtonBox(
             QDialogButtonBox::Ok|QDialogButtonBox::Cancel, this);
 
-    QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto mainWidget = new QWidget(this);
+    auto mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
     mainLayout->addWidget(mainWidget);
     mainLayout->setContentsMargins(0, 0, 0, 0);
@@ -65,11 +50,11 @@ KameraConfigDialog::KameraConfigDialog(Camera */*camera*/,
     okButton->setDefault(true);
     setModal( true );
 
-    QFrame *main = new QFrame(this);
+    auto main = new QFrame(this);
     mainLayout->addWidget(main);
 
     // Sets a layout for the frame, which is the parent of the GP_WIDGET_WINDOW
-    QVBoxLayout *topLayout = new QVBoxLayout(main);
+    auto topLayout = new QVBoxLayout(main);
     topLayout->setContentsMargins(0, 0, 0, 0);
 
     m_tabWidget = nullptr;
@@ -90,7 +75,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
     const char *widget_label;
     float widget_value_float;
     int widget_value_int;
-    const char *widget_value_string = NULL;
+    const char *widget_value_string = nullptr;
     gp_widget_get_type(widget, &widget_type);
     gp_widget_get_label(widget, &widget_label);
     gp_widget_get_info(widget, &widget_info);
@@ -111,20 +96,20 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
                 m_tabWidget = new QTabWidget(parent);
                 parent->layout()->addWidget(m_tabWidget);
             }
-            QWidget *tab = new QWidget;
+            auto tab = new QWidget;
             // widgets are to be aligned vertically in the tab
-            QVBoxLayout *tabLayout = new QVBoxLayout(tab);
+            auto tabLayout = new QVBoxLayout(tab);
             tabLayout->setContentsMargins(0, 0, 0, 0);
             m_tabWidget->addTab(tab, QString::fromLocal8Bit(widget_label));
 
             // Add scroll area
-            QScrollArea *scrollArea = new QScrollArea(tab);
+            auto scrollArea = new QScrollArea(tab);
             scrollArea->setWidgetResizable(true);
             scrollArea->setFrameShape(QFrame::NoFrame);
             tabLayout->addWidget(scrollArea);
 
             // Add a container widget to hold the page
-            QWidget *tabContainer = new QWidget(tab);
+            auto tabContainer = new QWidget(tab);
             // Add a layout for later parent->layout()->... calls
             new QVBoxLayout(tabContainer);
 
@@ -140,8 +125,8 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
     case GP_WIDGET_TOGGLE:
         {
             // Share the QGridLayout code
-            QWidget *grid = new QWidget(parent);
-            QGridLayout *gridLayout = new QGridLayout(grid);
+            auto grid = new QWidget(parent);
+            auto gridLayout = new QGridLayout(grid);
             grid->setLayout(gridLayout);
             parent->layout()->addWidget(grid);
 
@@ -151,7 +136,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
                 gp_widget_get_value(widget, &widget_value_string);
 
                 label = new QLabel(QString::fromLocal8Bit(widget_label)+QLatin1Char(':'), grid);
-                QLineEdit *lineEdit = new QLineEdit(widget_value_string, grid);
+                auto lineEdit = new QLineEdit(widget_value_string, grid);
 
                 gridLayout->addWidget(lineEdit, 0, 1, Qt::AlignRight);
                 m_wmap.insert(widget, lineEdit);
@@ -165,7 +150,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
                 gp_widget_get_value(widget, &widget_value_float);
 
                 label = new QLabel(QString::fromLocal8Bit(widget_label)+':', grid);
-                QSlider *slider = new QSlider(Qt::Horizontal, grid);
+                auto slider = new QSlider(Qt::Horizontal, grid);
 
                 gridLayout->addWidget(slider, 0, 1, Qt::AlignRight);
                 m_wmap.insert(widget, slider);
@@ -175,7 +160,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
                 gp_widget_get_value(widget, &widget_value_int);
 
                 label = new QLabel(QString::fromLocal8Bit(widget_label), grid);
-                QCheckBox *checkBox = new QCheckBox(grid);
+                auto checkBox = new QCheckBox(grid);
                 checkBox->setChecked(widget_value_int);
 
                 gridLayout->addWidget(checkBox, 0, 1, Qt::AlignRight);
@@ -198,7 +183,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
             } else {
                 layout = new QVBoxLayout;
             }
-            QGroupBox *buttonGroup = new QGroupBox(
+            auto buttonGroup = new QGroupBox(
                         QString::fromLocal8Bit(widget_label), parent);
             parent->layout()->addWidget(buttonGroup);
 
@@ -206,7 +191,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
                 const char *widget_choice;
                 gp_widget_get_choice(widget, i, &widget_choice);
 
-                QRadioButton *newestButton = new QRadioButton(widget_choice);
+                auto newestButton = new QRadioButton(widget_choice);
                 if(widget_value_string && !strcmp(widget_value_string, widget_choice)) {
                     newestButton->setChecked(true);
                 }
@@ -226,7 +211,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
         {
             gp_widget_get_value(widget, &widget_value_string);
 
-            QComboBox *comboBox = new QComboBox(parent);
+            auto comboBox = new QComboBox(parent);
             parent->layout()->addWidget(comboBox);
             comboBox->clear();
             for(int i = 0; i < gp_widget_count_choices(widget); ++i) {
@@ -251,7 +236,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
             // I can't see a way of implementing this. Since there is
             // no way of telling which button sent you a signal, we
             // can't map to the appropriate widget->callback
-            QLabel *label = new QLabel(i18n("Button (not supported by KControl)"), parent);
+            auto label = new QLabel(i18n("Button (not supported by KControl)"), parent);
             parent->layout()->addWidget(label);
 
             break;
@@ -259,7 +244,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
     case GP_WIDGET_DATE:
         {
             // TODO
-            QLabel * label = new QLabel(i18n("Date (not supported by KControl)"), parent);
+            auto  label = new QLabel(i18n("Date (not supported by KControl)"), parent);
             parent->layout()->addWidget(label);
 
             break;
@@ -278,10 +263,10 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
     if (widget_type == GP_WIDGET_SECTION) {
         // Get latest tab
         QWidget *tab = m_tabWidget->widget(m_tabWidget->count()-1);
-        QScrollArea *scrollArea =
+        auto scrollArea =
                 dynamic_cast<QScrollArea *>(tab->children().at(1));
         if (scrollArea) {
-            QVBoxLayout *vbox_layout =
+            auto vbox_layout =
                 dynamic_cast<QVBoxLayout *>(scrollArea->widget()->layout());
             if (vbox_layout) {
                 vbox_layout->addStretch();
@@ -304,14 +289,14 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
         break;
     case GP_WIDGET_TEXT:
         {
-            QLineEdit *lineEdit = static_cast<QLineEdit *>(m_wmap[widget]);
+            auto lineEdit = static_cast<QLineEdit *>(m_wmap[widget]);
             gp_widget_set_value(widget, (void *)lineEdit->text().toLocal8Bit().data());
 
             break;
         }
     case GP_WIDGET_RANGE:
         {
-            QSlider *slider = static_cast<QSlider *>(m_wmap[widget]);
+            auto slider = static_cast<QSlider *>(m_wmap[widget]);
             float value_float = slider->value();
             gp_widget_set_value(widget, (void *)&value_float);
 
@@ -319,7 +304,7 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
         }
     case GP_WIDGET_TOGGLE:
         {
-            QCheckBox *checkBox = static_cast<QCheckBox *>(m_wmap[widget]);
+            auto checkBox = static_cast<QCheckBox *>(m_wmap[widget]);
             int value_int = checkBox->isChecked() ? 1 : 0;
             gp_widget_set_value(widget, (void *)&value_int);
 
@@ -327,9 +312,9 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
         }
     case GP_WIDGET_RADIO:
         {
-            QGroupBox *buttonGroup = static_cast<QGroupBox *>(m_wmap[widget]);
+            auto buttonGroup = static_cast<QGroupBox *>(m_wmap[widget]);
             for (auto button : buttonGroup->children()) {
-                QRadioButton *radButton = static_cast<QRadioButton *>(button);
+                auto radButton = static_cast<QRadioButton *>(button);
                 if (radButton->isChecked()) {
                     gp_widget_set_value(widget,
                             (void *)radButton->text().toLocal8Bit().data());
@@ -340,7 +325,7 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
         }
     case GP_WIDGET_MENU:
         {
-            QComboBox *comboBox = static_cast<QComboBox *>(m_wmap[widget]);
+            auto comboBox = static_cast<QComboBox *>(m_wmap[widget]);
             gp_widget_set_value(widget,
                     (void *)comboBox->currentText().toLocal8Bit().data());
 
