@@ -1,24 +1,10 @@
 /*
+    SPDX-FileCopyrightText: 2001 The Kompany
+    SPDX-FileCopyrightText: 2002-2003 Ilya Konstantinov <kde-devel@future.shiny.co.il>
+    SPDX-FileCopyrightText: 2002-2003 Marcus Meissner <marcus@jet.franken.de>
+    SPDX-FileCopyrightText: 2003 Nadeem Hasan <nhasan@nadmm.com>
 
-    Copyright (C) 2001 The Kompany
-          2002-2003	Ilya Konstantinov <kde-devel@future.shiny.co.il>
-          2002-2003	Marcus Meissner <marcus@jet.franken.de>
-          2003		Nadeem Hasan <nhasan@nadmm.com>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kameradevice.h"
@@ -71,8 +57,8 @@ KCamera::KCamera(const QString &name, const QString &path)
     m_name	= name;
     m_model	= name;
     m_path	= path;
-    m_camera = NULL;
-    m_abilitylist = NULL;
+    m_camera = nullptr;
+    m_abilitylist = nullptr;
 }
 
 KCamera::~KCamera()
@@ -142,7 +128,7 @@ bool KCamera::initCamera()
         result = gp_camera_init(m_camera, glob_context);
         if (result != GP_OK) {
             gp_camera_free(m_camera);
-            m_camera = NULL;
+            m_camera = nullptr;
             Q_EMIT error(
                 i18n("Unable to initialize camera. Check your port settings and camera connectivity and try again."),
                 QString::fromLocal8Bit(gp_result_as_string(result)));
@@ -258,7 +244,7 @@ void KCamera::invalidateCamera()
 {
     if (m_camera) {
         gp_camera_free(m_camera);
-        m_camera = NULL;
+        m_camera = nullptr;
     }
 }
 
